@@ -323,6 +323,7 @@ static void print_connector_macros(cmacro_context *cmc, const Exp *n)
 		print_expression_tag_end(cmc->dict, cmc->e, n, &cmc->indent);
 }
 
+/* Note: The returned value is to be freed by the caller. */
 static char *lg_exp_stringify_with_tags(Dictionary dict, const Exp *n,
                                         bool show_macros)
 {
@@ -337,6 +338,7 @@ static char *lg_exp_stringify_with_tags(Dictionary dict, const Exp *n,
 
 /**
  * Stringify the given expression, ignoring tags.
+ * Note: The returned value is to be freed by the caller.
  */
 char *lg_exp_stringify(const Exp *n)
 {
@@ -350,8 +352,9 @@ const char *exp_stringify(const Exp *n)
 	static TLS char *s;
 
 	free(s);
+	s = NULL;
 	if (n == NULL) return ("(null)");
-	s = strdup(lg_exp_stringify_with_tags(NULL, n, false));
+	s = lg_exp_stringify_with_tags(NULL, n, false);
 	return s;
 }
 
@@ -636,6 +639,8 @@ static void dyn_print_disjunct_list(dyn_str *s, const Disjunct *dj,
 {
 	int djn = 0;
 	char word[MAX_WORD + 32];
+	int max_ccnt = 0;
+	int *exp_pos = NULL;
 	bool print_disjunct_address = test_enabled("disjunct-address");
 
 	for (;dj != NULL; dj=dj->next)
@@ -664,6 +669,7 @@ static void dyn_print_disjunct_list(dyn_str *s, const Disjunct *dj,
 		dyn_print_connector_list(l, dj->right, /*dir*/1, flags);
 
 		char *ls = dyn_str_take(l);
+
 		if ((NULL == select) || select(ls, criterion))
 		{
 			dyn_strcat(s, ls);
@@ -671,14 +677,19 @@ static void dyn_print_disjunct_list(dyn_str *s, const Disjunct *dj,
 
 			if ((criterion != NULL) && (criterion->exp != NULL))
 			{
-				int ccnt = 1;
+				int ccnt = 1; /* 1 for exp_pos -1 terminator. */
 				for (Connector *c = dj->left; c != NULL; c = c->next)
 					ccnt++;
 				for (Connector *c = dj->right; c != NULL; c = c->next)
 					ccnt++;
 
-				int *exp_pos = alloca(ccnt * sizeof(int));
+				if (ccnt > max_ccnt)
+				{
+					max_ccnt = (ccnt == 0) ? 32 : ccnt;
+					exp_pos = alloca(max_ccnt * sizeof(int));
+				}
 				int *i = exp_pos;
+
 				for (Connector *c = dj->left; c != NULL; c = c->next)
 					*i++ = c->exp_pos;
 				for (Connector *c = dj->right; c != NULL; c = c->next)
@@ -798,7 +809,7 @@ static char *display_disjuncts(Dictionary dict, const Dict_node *dn,
 		                                      max_cost, NULL);
 
 		unsigned int dnum0 = count_disjuncts(d);
-		d = eliminate_duplicate_disjuncts(d, NULL);
+		d = eliminate_duplicate_disjuncts(d, false);
 		unsigned int dnum1 = count_disjuncts(d);
 
 		if ((flags != NULL) && (strchr(flags, 'm') != NULL))
@@ -873,7 +884,7 @@ static Regex_node *new_disjunct_regex_node(Regex_node *current, char *regpat)
 {
 	Regex_node *rn = malloc(sizeof(Regex_node));
 
-	rn->name = strdup("Disjunct regex");
+	rn->name = "Disjunct regex";
 	rn->pattern = strdup(regpat);
 	rn->re = NULL;
 	rn->neg = false;
@@ -916,7 +927,7 @@ static Regex_node *make_disjunct_pattern(const char *pattern, const char *flags)
 		for (size_t i = 0; i < pat_len; i++)
 		{
 			const char *c =  &pattern[i];
-			if (!isalnum(*c) && (strchr("*+- ", *c) == NULL))
+			if (!isalnum((unsigned char)*c) && (strchr("*+- ", *c) == NULL))
 			{
 				prt_error("Warning: Invalid character \"%.*s\" in full "
 				          "disjunct specification.\n",
@@ -991,7 +1002,7 @@ static Regex_node *make_disjunct_pattern(const char *pattern, const char *flags)
 	if (NULL == rn)
 		rn = new_disjunct_regex_node(NULL, regpat);
 
-	if (compile_regexs(rn, NULL) != 0)
+	if (!compile_regexs(rn, NULL))
 		return NULL; /* compile_regexs() issues the error message */
 
 	return rn;
@@ -1236,12 +1247,13 @@ static char *display_expr(Dictionary dict, const char *word, Dict_node *dn,
 			dyn_strcat(s, "\n\n");
 		}
 
-		const char *expstr = lg_exp_stringify_with_tags(dict, e, show_macros);
+		char *expstr = lg_exp_stringify_with_tags(dict, e, show_macros);
 
 		append_string(s, "    %-*s %s",
 		              display_width(DJ_COL_WIDTH, dn->string), dn->string,
 		              expstr);
 		dyn_strcat(s, "\n\n");
+		free(expstr);
 	}
 
 	if (Exp_pool != NULL) pool_delete(Exp_pool);
