@@ -15,7 +15,7 @@
 
 #include "build-disjuncts.h"
 #include "connectors.h"
-#include "dict-common/dict-structures.h"  // Exp_struct, lg_exp_stringify
+#include "dict-common/dict-structures.h"  // Exp_struct, exp_stringify
 #include "dict-common/dict-common.h"      // Dictionary
 #include "disjunct-utils.h"
 #include "utilities.h"
@@ -293,9 +293,14 @@ build_disjunct(Sentence sent, Clause * cl, const char * string,
 			*loc = n;         /* update the connector list */
 		}
 
+		bool sat_solver = false;
+#if USE_SAT_SOLVER
+		sat_solver = opts->use_sat_solver;
+#endif /* USE_SAT_SOLVER */
+
 		/* XXX add_category() starts category strings by ' '.
 		 * FIXME Replace it by a better indication. */
-		if (!IS_GENERATION(sent->dict) || (' ' != string[0]))
+		if (sat_solver || (!IS_GENERATION(sent->dict) || (' ' != string[0])))
 		{
 			ndis->word_string = string;
 			ndis->cost = cl->cost;
@@ -309,7 +314,8 @@ build_disjunct(Sentence sent, Clause * cl, const char * string,
 			ndis->num_categories = 1;
 			ndis->category[0].num = strtol(string, NULL, 16);
 			ndis->category[1].num = 0; /* API array terminator */
-			assert((ndis->category[0].num > 0) && (ndis->category[0].num < 64*1024),
+			assert(sat_solver || ((ndis->category[0].num > 0) &&
+			       (ndis->category[0].num < 64*1024)),
 			       "Insane category %u", ndis->category[0].num);
 			ndis->category[0].cost = cl->cost;
 		}
@@ -337,7 +343,7 @@ Disjunct *build_disjuncts_for_exp(Sentence sent, Exp* exp, const char *word,
 	                   /*num_elements*/32768, sizeof(Tconnector),
 	                   /*zero_out*/false, /*align*/false, /*exact*/false);
 
-	// printf("%s\n", lg_exp_stringify(exp));
+	// printf("%s\n", exp_stringify(exp));
 	c = build_clause(exp, &ct);
 	// print_clause_list(c);
 	dis = build_disjunct(sent, c, word, gs, cost_cutoff, opts);
